==> wow-core-0.5.0-sources.jar: me/ahoo/wow/saga/stateless/StatelessSagaFunctionRegistrar.kt <==
/*
 * Copyright [2021-present] [ahoo wang <ahoowang@qq.com> (https://github.com/Ahoo-Wang)].
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *      http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package me.ahoo.wow.saga.stateless

import me.ahoo.wow.command.CommandBus
import me.ahoo.wow.event.AbstractEventFunctionRegistrar
import me.ahoo.wow.event.DomainEvent
import me.ahoo.wow.messaging.function.MessageFunction
import me.ahoo.wow.messaging.function.MultipleMessageFunctionRegistrar
import me.ahoo.wow.messaging.function.SimpleMultipleMessageFunctionRegistrar
import me.ahoo.wow.saga.annotation.asStatelessSagaMetadata
import reactor.core.publisher.Mono

class StatelessSagaFunctionRegistrar(
    actual: MultipleMessageFunctionRegistrar<MessageFunction<Any, DomainEvent<*>, Mono<*>>> = SimpleMultipleMessageFunctionRegistrar()
) : AbstractEventFunctionRegistrar<Mono<*>>(actual) {

    fun registerStatelessSaga(statelessSaga: Any, commandBus: CommandBus) {
        statelessSaga.javaClass
            .asStatelessSagaMetadata()
            .asMessageFunctionRegistry(statelessSaga)
            .forEach {
                val statelessSagaHandler = StatelessSagaFunction(it.value, commandBus)
                register(statelessSagaHandler)
            }
    }
}

==> wow-core-1.8.20-sources.jar: me/ahoo/wow/saga/stateless/StatelessSagaFunctionRegistrar.kt <==
/*
 * Copyright [2021-present] [ahoo wang <ahoowang@qq.com> (https://github.com/Ahoo-Wang)].
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *      http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package me.ahoo.wow.saga.stateless

import me.ahoo.wow.command.CommandBus
import me.ahoo.wow.event.AbstractEventFunctionRegistrar
import me.ahoo.wow.event.DomainEventExchange
import me.ahoo.wow.messaging.function.MessageFunction
import me.ahoo.wow.messaging.function.MultipleMessageFunctionRegistrar
import me.ahoo.wow.messaging.function.SimpleMultipleMessageFunctionRegistrar
import me.ahoo.wow.saga.annotation.asStatelessSagaMetadata
import reactor.core.publisher.Mono

class StatelessSagaFunctionRegistrar(
    actual: MultipleMessageFunctionRegistrar<MessageFunction<Any, DomainEventExchange<*>, Mono<*>>> = SimpleMultipleMessageFunctionRegistrar(),
) : AbstractEventFunctionRegistrar<Mono<*>>(actual) {

    fun registerStatelessSaga(statelessSaga: Any, commandBus: CommandBus) {
        statelessSaga.javaClass
            .asStatelessSagaMetadata()
            .asMessageFunctionRegistry(statelessSaga)
            .forEach {
                val statelessSagaHandler = StatelessSagaFunction(it, commandBus)
                register(statelessSagaHandler)
            }
    }
}
